@@ -207,7 +207,7 @@ class dyn_vec:
             self.parent_rf.ob.keyframe_insert(data_path='scale', frame=cur_frame)
 
 class anim_text:
-    def __init__(self, name, parent, anim):
+    def __init__(self, name, parent, anim, data, label, fix_place, if_str):
 
         self.anim = anim
 
@@ -221,12 +221,9 @@ class anim_text:
         self.name = name
 
 
-    def animate(self, data, label, fix_place, if_str):
-        anim = self.anim
-
         if not(if_str):
             def update(self):
-                text = bpy.data.objects[self.name+'_text']
+                text = bpy.data.objects[name+'_text']
                 cur_frame = bpy.context.scene.frame_current
                 
                 if np.any(cur_frame == anim.frames):
@@ -235,7 +232,7 @@ class anim_text:
                     
         else:
             def update(self):
-                text = bpy.data.objects[self.name+'_text']
+                text = bpy.data.objects[name+'_text']
                 cur_frame = bpy.context.scene.frame_current
                 
                 if np.any(cur_frame == anim.frames):
